# Library Overview

The _Planet Auth Library_ provides two top level packages:

* `planet_auth` - Core authentication library functionality.  This is where clients for various
    authentication protocols are implemented.
    See [planet_auth][] for library API details
* `planet_auth_utils` - Higher level utility functionality built on top of the core library.
    See [planet_auth_utils][] for library API details.
